<?php
/**
 * This is the template for displaying single events within Mobile.
 *
 * @package      Builder Block Events
 * @subpackage   Mobile Templates
 * @author       Justin Kopepasah
 * @since        1.0.6
 *
 * DO NOT EDIT THIS TEMPLATE.
 *
 * If you wish to use a custom single template copy this
 * template over to your theme and rename the template to 
 * single-it_bb_event.php.
*/

get_header();
		
global $post, $_wp_additional_image_sizes;
		
$post_options = apply_filters( "it_bb_event_get_post_meta_values", array() );
$it_bb_event_settings = apply_filters( 'it_bb_event_load_data', array() );
		
// Get today's date and the events date for comparison later.
$todays_date = strtotime( date('Y-m-d') );
$event_ended = strtotime( $post_options[ 'event_end_date' ] );
		
/**
 *	We need to set up the map to use a default venue or a custom location.
*/
		
// First check to see if a default location is set.
if ( isset( $post_options['default_location'] ) ) {
	// If a custom location is choosen for the event location, use this data.
	if ( $post_options['default_location'] == 'custom' ) {
				
		// Address.
		$event_address 		= $post_options['event_address'];
				
		// Map variables.
		$map_type				= $post_options['map_type'];
		$map_zoom				= $post_options['map_zoom'];
		$marker_latitude		= $post_options['marker_latitude'];
		$marker_longitude		= $post_options['marker_longitude'];
			
	}
	// If a Venue is used, use date from the choosen Venue.
	else {
		// First we need to reset the query.
		$venue = new WP_Query(
			array(
				'post_type' => 'it_bb_event_venue',
				'p' 		=> $post_options['default_location'],
			)
		);
		while ( $venue->have_posts() ) : $venue->the_post();
					
			// All the default venue options.
			$venue_options = get_post_meta( $venue->post->ID, '_it_options', true );
					
			// Address.
			$event_address 		= $venue_options['event_address'];
					
			// Map variables.
			$map_type				= $venue_options['map_type'];
			$map_zoom				= $venue_options['map_zoom'];
			$marker_latitude		= $venue_options['marker_latitude'];
			$marker_longitude		= $venue_options['marker_longitude'];
					
		endwhile;
				
		// Reset Query
		wp_reset_query();
	}
}
else {
	// Address.
	$event_address = $post_options['event_address'];
			
	// Map variables.
	$map_type				= $post_options['map_type'];
	$map_zoom				= $post_options['map_zoom'];
	$marker_latitude		= $post_options['marker_latitude'];
	$marker_longitude		= $post_options['marker_longitude'];
}
?>
	<?php if ( have_posts() ) : ?>
		<div class="loop">
			<div class="loop-content">
				<?php while ( have_posts() ) : // The Loop ?>
					<?php the_post(); ?>
					
					<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
						
						<div class="event-notifications">
							<?php
							if ( $event_ended < $todays_date && ! empty( $event_ended ) ) {
								echo '<p class="error event-over">' . $it_bb_event_settings['it_bb_event_ended'] . '</p>';
							}
							if ( ! empty( $post_options['event_canceled'] ) ) {
								echo '<p class="error">' . $it_bb_event_settings['it_bb_event_canceled'] . '</p>';
							}
							if ( ! empty( $post_options['event_postponed'] ) ) {
								echo '<p class="notice">' . $it_bb_event_settings['it_bb_event_postponed'] . '</p>';
							}
							?>
						</div>
						
						<div class="entry-header clearfix">
							
							<h2 class="entry-title"><?php the_title(); ?></h2>
							
							<div class="entry-image-wrapper<?php if ( isset( $_wp_additional_image_sizes['event-single'] ) && ( $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), array( 960, 960 ) ) ) && $image[1] >= 960 ) { echo ' event-single'; } ?>">
								<div class="entry-image">
									<?php
									if ( has_post_thumbnail() ) {
										if ( ( $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), array( 960, 960 ) ) ) && $image[1] >= 960 ) {
											the_post_thumbnail( 'event-single' );
										}
										else {
											the_post_thumbnail();
										}
									}
									?>
								</div>
							</div>
							
							<?php if ( ! empty( $post_options[ 'event_start_date' ] ) || ! empty( $post_options[ 'event_end_date' ] ) ) : ?>
								<div class="entry-meta event-start-end clearfix">
									<div class="alignleft start-date">
										<span><strong><?php _e( 'Date: ', 'it-l10n-builder-block-events' ); ?></strong></span>
										<?php echo mysql2date( get_option( 'date_format' ), $post_options[ 'event_start_date' ] ); ?>
										<?php if ( $post_options[ 'event_start_date' ] !== $post_options[ 'event_end_date' ] ) : ?>
											<?php echo ' to ' . mysql2date( get_option( 'date_format' ), $post_options[ 'event_end_date' ] ); ?>
										<?php endif; ?>
									</div>
								</div>
							<?php endif; ?>
							
							<div class="entry-meta clearfix">
								<?php if ( isset( $post_options[ 'eventbrite_event' ] ) ) : ?>
									<?php if ( $post_options[ 'eventbrite_event' ] != 'invert-custom' && ! empty( $post_options['eventbrite_button_widget'] ) && ! empty( $it_bb_event_settings['eventbrite_api_key'] ) ) : ?>
										<div class="alignright eventbrite-button">
											<a class="btn btn-eventbrite" href="http://www.eventbrite.com/event/<?php echo $post_options['eventbrite_event']; ?>?ref=ebtnebtckt" target="_blank"><?php _e( 'Register on Eventbrite', 'it-l10n-builder-block-events' ); ?></a>		
										</div>
									<?php endif; ?>
								<?php endif; ?>
								<?php if ( ! empty( $post_options[ 'event_start_date' ] ) && ! empty( $post_options[ 'event_end_date' ] ) ) : ?>
									<div class="add-to-calendar">
										<a class="btn btn-gcal" href="http://www.google.com/calendar/event?action=TEMPLATE&text=<?php echo urlencode( html_entity_decode( get_the_title(), ENT_QUOTES, 'UTF-8' ) ); ?>&dates=<?php echo str_replace( '-', '', $post_options[ 'event_start_date' ] ) ?>/<?php echo str_replace( '-', '', $post_options[ 'event_end_date' ] ) ?>&details=<?php echo urlencode( html_entity_decode( strip_tags( get_the_excerpt() ), ENT_QUOTES, 'UTF-8' ) ); ?>&location=<?php echo urlencode( str_replace( "\n", " ", html_entity_decode( $event_address, ENT_QUOTES, 'UTF-8' ) ) ); ?>&trp=false" target="_blank"><?php _e( 'Add to Google Calendar', 'it-l10n-builder-block-events' ); ?></a>
									</div>
								<?php endif; ?>
							</div>
						</div>
						
						<div class="entry-content clearfix">
							<?php the_content(); ?>
							<?php wp_link_pages( array( 'before' => '<p class="entry-utility"><strong>' . __( 'Pages:', 'it-l10n-builder-block-events' ) . '</strong> ', 'after' => '</p>', 'next_or_number' => 'number' ) ); ?>
						</div>
						
						<?php if ( ! empty( $event_address ) || ! empty( $marker_latitude ) ) : ?>
							<div id="event-location" class="entry-block">
								<div class="event-address-directions-wrapper">
									
									<?php if ( ! empty( $event_address ) ) : ?>
										<div class="event-address event-column">
											<h4><?php _e( 'Address', 'it-l10n-builder-block-events' ); ?></h4>
											<p><?php print( nl2br( $event_address ) ); ?></p>
											<?php if ( ! empty( $marker_latitude ) ) : ?>
												<a class="btn btn-primary" href="http://maps.google.com/maps?q=<?php echo $marker_latitude ?>,+<?php echo $marker_longitude ?>+(<?php echo urlencode( html_entity_decode( get_the_title(), ENT_QUOTES, 'UTF-8' ) ); ?>)" title="Open in Google" target="_blank"><?php _e( 'Open in Google Maps', 'it-l10n-builder-block-events' ); ?></a>
											<?php else : ?>
												<a class="btn btn-primary" href="http://maps.google.com/maps?q=<?php echo urlencode( str_replace( "\n", " ", html_entity_decode( $event_address, ENT_QUOTES, 'UTF-8' ) ) ); ?>" title="Open in Google" target="_blank"><?php _e( 'Search in Google Maps', 'it-l10n-builder-block-events' ); ?></a>
											<?php endif; ?>
										</div>
									<?php endif; ?>
									
									<?php if ( ! empty( $marker_latitude ) ) : ?>
										<div class="event-directions event-column">
											<h4><?php _e( 'Get Directions', 'it-l10n-builder-block-events' ); ?></h4>	
											<form class="location-directions-form">
												<p><input type="text" id="directions_origin" name="directions_origin" placeholder="Enter Address" /></p>
												<p><?php _e( 'How are you getting there?', 'it-l10n-builder-block-events' ); ?></p>
												<p>
													<select id="directions_method" name="directions_method">
														<option value="BICYCLING"><?php _e( 'Bicycling', 'it-l10n-builder-block-events' ); ?></option>
														<option value="DRIVING" selected="selected"><?php _e( 'Driving', 'it-l10n-builder-block-events' ); ?></option>
														<option value="WALKING"><?php _e( 'Walking', 'it-l10n-builder-block-events' ); ?></option>
													</select>
													<input type="button" id="directions_calculate_route" name="directions_calculate_route" value="<?php _e( 'Create Route', 'it-l10n-builder-block-events' ); ?>" />
												</p>
											</form>
										</div>
									<?php endif; ?>
								</div>
								
								<?php if ( ! empty( $marker_latitude ) ) : ?>
									<div id="map-and-directions">
										<p class="success" style="text-align:center;display:none;"><?php _e( 'View map and directions below.', 'it-l10n-builder-block-events' ); ?></p>
										<h4><?php _e( 'Map', 'it-l10n-builder-block-events' ); ?></h4>
										<div style="overflow:auto;clear:both" class="map_canvas_wrapper">
											<input type="hidden" id="map_center_latitude" name="map_center_latitude" value="<?php echo $marker_latitude; ?>" />
											<input type="hidden" id="map_center_longitude" name="map_center_longitude" value="<?php echo $marker_longitude; ?>" />
											<input type="hidden" id="map_type" name="map_type" value="<?php echo $map_type; ?>" />
											<input type="hidden" id="map_zoom" name="map_zoom" value="<?php echo $map_zoom; ?>" />
											<input type="hidden" id="marker_latitude" name="marker_latitude" value="<?php echo $marker_latitude; ?>" />
											<input type="hidden" id="marker_longitude" name="marker_longitude" value="<?php echo $marker_longitude; ?>" />
										
											<div id="map_canvas" style="width:100%; height:400px"></div>
										</div>
										<div class="meta-box" id="text-directions">
											<h4 style="display:none;"><?php _e( 'Directions', 'it-l10n-builder-block-events' ); ?></h4>
										</div>
									</div>
								<?php endif; ?>
							</div><!-- end #event-location -->
						<?php endif; ?>
						
						<?php if ( class_exists( 'RGForms' ) && isset( $post_options[ 'gform_register' ] ) && $post_options[ 'gform_register' ] != 'invert-custom' ) : ?>
							<div class="event-gravity entry-block">
								<?php
								
								$form_items = array(
									'title'       => $post_options[ 'gform_display_title' ],
									'description' => $post_options[ 'gform_display_description' ],
									'ajax'        => $post_options[ 'gform_enable_ajax' ],
								);
								
								foreach ( $form_items as $form_var => $form_val ) {
									$form_args[ $form_var ] = ( $form_val ? true : false );
								}
								
								gravity_form( $post_options[ 'gform_register' ], $form_args['title'], $form_args['description'], false, '', $form_args['ajax'] );
								
								?>
							</div>
						<?php endif; ?>
						
						<?php if ( isset( $post_options[ 'eventbrite_event' ] ) ) : ?>
							<?php if ( $post_options[ 'eventbrite_event' ] != 'invert-custom' && ! empty( $post_options[ 'eventbrite_ticket_widget' ] ) && ! empty( $it_bb_event_settings['eventbrite_api_key'] ) ) : ?>
								<div class="event-brite entry-block">
									<div style="width:100%;">
										<iframe src="http://www.eventbrite.com/tickets-external?eid=<?php echo $post_options['eventbrite_event']; ?>&amp;ref=etckt" frameborder="0" height="192" width="100%" vspace="0" hspace="0" marginheight="5" marginwidth="5" scrolling="auto" allowtransparency="true"></iframe>
									</div>
								</div>
							<?php endif; ?>
						<?php endif; ?>
						
						<?php comments_template(); // include comments template ?>
						
						<div class="entry-footer clearfix">
							<div class="entry-meta event-meta">
								<?php printf( __( ' on %s', 'it-l10n-builder-block-events' ), '<span>' . get_the_date() . '</span>' ); ?>
							</div>
						</div>
					</div>
					<?php endwhile; // end of one post ?>
				</div>
						
			<div class="loop-footer clearfix">
				<div class="loop-utility alignleft"><?php previous_posts_link( __( '&laquo; Previous Page', 'it-l10n-builder-block-events' ) ); ?></div>
				<div class="loop-utility alignright"><?php next_posts_link( __( 'Next Page &raquo;', 'it-l10n-builder-block-events' ) ); ?></div>
			</div>
			
		</div>
				
	<?php else : ?>
		<div id="infoblock">
			<h2>Page Not Found</h2>
		</div>
		<div class="content">
			<p>Whoops, looks like that page doesn't exist...</p>
		</div>
	<?php endif; ?>

<?php get_footer(); ?>